@@ -1,5 +1,9 @@
 use super::*;
 
+pub use template::{KubeadmConfigTemplate, KubeadmConfigTemplateSpec};
+
+mod template;
+
 /// KubeadmConfigSpec defines the desired state of KubeadmConfig.
 /// Either ClusterConfiguration and InitConfiguration should be defined or the JoinConfiguration should be defined.
 #[derive(Clone, Debug, Default, Serialize, Deserialize)]
