@@ -75,9 +75,9 @@ impl AWSCluster {
         }
     }
 
-    pub fn add_subnet(self, availability_zone: &str, cidr_block: &str, is_public: bool) -> Self {
-        let network = self.spec.network.unwrap_or_default();
-        let mut subnets = network.subnets.unwrap_or_default().0;
+    pub fn add_subnet(&mut self, availability_zone: &str, cidr_block: &str, is_public: bool) {
+        let network = self.spec.network.take().unwrap_or_default();
+        let network::Subnets(mut subnets) = network.subnets.unwrap_or_default();
         subnets.push(network::SubnetSpec {
             availability_zone: Some(availability_zone.to_string()),
             cidr_block: Some(cidr_block.to_string()),
@@ -88,12 +88,6 @@ impl AWSCluster {
             subnets: Some(network::Subnets(subnets)),
             ..network
         };
-        Self {
-            spec: AWSClusterSpec {
-                network: Some(network),
-                ..self.spec
-            },
-            ..self
-        }
+        self.spec.network = Some(network);
     }
 }
